@@ -5,7 +5,6 @@ from .model_based import EnvFnMixin
 from .model_based import ModelSamplingMixin
 from .model_based import ModelTrainingMixin
 from .optimizer_collection import OptimizerCollection
-from .target_networks_mixin import TargetNetworksMixin
 from .torch_policy import TorchPolicy
 
 __all__ = [
@@ -13,7 +12,6 @@ __all__ = [
     "EnvFnMixin",
     "ModelSamplingMixin",
     "ModelTrainingMixin",
-    "TargetNetworksMixin",
     "TorchPolicy",
     "OptimizerCollection",
 ]
